@@ -37,7 +37,7 @@ test_that("Adding Sumstats to a model works", {
 
 test_that("Calculation of sumstats works", {
   stat_sum_class <- R6::R6Class("Stat_Sum", inherit = sumstat_class,
-    public = list(calculate = function(seg_sites, trees, files, model) {
+    public = list(calculate = function(seg_sites, ...) {
       sapply(seg_sites, sum)
     })
   )
@@ -54,7 +54,7 @@ test_that("Calculation of sumstats works", {
 
 test_that("Calculation of sumstats from simresults works", {
   stat_sum_class <- R6::R6Class("Stat_Sum", inherit = sumstat_class,
-    public = list(calculate = function(seg_sites, trees, files, model) {
+    public = list(calculate = function(seg_sites, ...) {
       sapply(seg_sites, sum)
     })
   )
@@ -62,7 +62,7 @@ test_that("Calculation of sumstats from simresults works", {
   model <- coal_model(5:6, 10) + stat_sum_class$new("sum", identity) +
     stat_sum_class$new("sum2", identity)
   stats <- calc_sumstats_from_sim(list(1:3, 1:5, 7), NULL, "", model, 1:2,
-                                  1:3, get_simulator("scrm"))
+                                  1:3, list(get_simulator("scrm")))
   expect_equal(stats$sum,  c(6, 15, 7))
   expect_equal(stats$sum2, c(6, 15, 7))
   expect_equal(stats$cmds, 1:3)
@@ -72,7 +72,7 @@ test_that("Calculation of sumstats from simresults works", {
 
 test_that("Calculation of sumstats respects transformations", {
   stat_sum_class <- R6::R6Class("Stat_Sum", inherit = sumstat_class,
-    public = list(calculate = function(seg_sites, trees, files, model) {
+    public = list(calculate = function(seg_sites, ...) {
       sapply(seg_sites, sum)
     })
   )
